aboutsummaryrefslogtreecommitdiff
path: root/build_matrix.sh
diff options
context:
space:
mode:
authorFrancois-Xavier Le Bail <devel.fx.lebail@orange.fr>2023-05-23 11:00:57 +0200
committerfxlb <devel.fx.lebail@orange.fr>2023-05-23 11:57:46 +0000
commiteb324d58b651674764c17ed63dddc568952ffed9 (patch)
tree4e0e0891ced3c7bb70ceaa82cc64f9f50d994824 /build_matrix.sh
parent69a08f5c1043f6dd9374ae9cf1d2c11b49caed0a (diff)
CI: Test with IPv6 support enabled/disabled
Diffstat (limited to 'build_matrix.sh')
-rwxr-xr-xbuild_matrix.sh31
1 files changed, 18 insertions, 13 deletions
diff --git a/build_matrix.sh b/build_matrix.sh
index 47978644..0c9bec26 100755
--- a/build_matrix.sh
+++ b/build_matrix.sh
@@ -1,10 +1,11 @@
#!/bin/sh -e
# This script executes the matrix loops, exclude tests and cleaning.
# The matrix can be configured with the following environment variables: MATRIX_CC,
# MATRIX_CMAKE and MATRIX_REMOTE.
: "${MATRIX_CC:=gcc clang}"
: "${MATRIX_CMAKE:=no yes}"
+: "${MATRIX_IPV6:=no yes}"
: "${MATRIX_REMOTE:=no yes}"
# Set this variable to "yes" before calling this script to disregard all cmake
# warnings in a particular environment (CI or a local working copy). Set it
@@ -22,7 +23,7 @@
# GNU Make available as "gmake".
: "${MAKE_BIN:=make}"
# It calls the build.sh script which runs one build with setup environment
# variables: CC, CMAKE and REMOTE.
. ./build_common.sh
print_sysinfo
@@ -50,16 +51,20 @@ for CC in $MATRIX_CC; do
fi
for CMAKE in $MATRIX_CMAKE; do
export CMAKE
- for REMOTE in $MATRIX_REMOTE; do
- export REMOTE
- COUNT=`increment $COUNT`
- echo_magenta "===== SETUP $COUNT: CC=$CC CMAKE=$CMAKE REMOTE=$REMOTE =====" >&2
- # Run one build with setup environment variables: CC, CMAKE and REMOTE
- run_after_echo ./build.sh
- echo 'Cleaning...'
- if [ "$CMAKE" = yes ]; then rm -rf build; else "$MAKE_BIN" distclean; fi
- purge_directory "$PREFIX"
- run_after_echo git status -suall
+ for IPV6 in $MATRIX_IPV6; do
+ export IPV6
+ for REMOTE in $MATRIX_REMOTE; do
+ export REMOTE
+ COUNT=`increment $COUNT`
+ echo_magenta "===== SETUP $COUNT: CC=$CC CMAKE=$CMAKE IPV6=$IPV6 REMOTE=$REMOTE =====" >&2
+ # Run one build with setup environment variables: CC, CMAKE,
+ # IPV6 and REMOTE
+ run_after_echo ./build.sh
+ echo 'Cleaning...'
+ if [ "$CMAKE" = yes ]; then rm -rf build; else "$MAKE_BIN" distclean; fi
+ purge_directory "$PREFIX"
+ run_after_echo git status -suall
+ done
done
done
done
@@ -1,10 +1,11 @@
#!/bin/sh -e
# This script executes the matrix loops, exclude tests and cleaning.
-# The matrix can be configured with the following environment variables: MATRIX_CC,
-# MATRIX_CMAKE and MATRIX_REMOTE.
+# The matrix can be configured with the following environment variables:
+# MATRIX_CC, MATRIX_CMAKE, MATRIX_IPV6 and MATRIX_REMOTE.
: "${MATRIX_CC:=gcc clang}"
: "${MATRIX_CMAKE:=no yes}"
@@ -22,7 +23,7 @@
: "${MAKE_BIN:=make}"
# It calls the build.sh script which runs one build with setup environment
-# variables: CC, CMAKE and REMOTE.
+# variables: CC, CMAKE, IPV6 and REMOTE.
. ./build_common.sh
print_sysinfo